#
# spec file for package MozillaFirefox-branding-SLE
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define major 128
%define major_plus %( echo $((%{major}+1)) )

BuildRequires:  MozillaFirefox
BuildRequires:  unzip
BuildRequires:  zip
%if 0%{?suse_version} > 1200
BuildRequires:  gconf2-devel
%endif

Name:           MozillaFirefox-branding-SLE
Version:        %{major}
Release:        150200.9.18.1
Summary:        SLED branding of MozillaFirefox
License:        BSD-3-Clause
Group:          Productivity/Networking/Web/Browsers
Source:         COPYING
Source3:        firefox-SLE.js
Source4:        firefox.schemas
Source5:        distribution.ini.in
Source6:        all-SLE.js
Source8:        README.SUSE
PreReq:         MozillaFirefox >= %{major}
PreReq:         MozillaFirefox < %{major_plus}
Supplements:    packageand(MozillaFirefox:branding-SLE)
Provides:       MozillaFirefox-branding = %{version}
Conflicts:      otherproviders(MozillaFirefox-branding)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define homepage https://www.suse.com/
%define progdir %{_libdir}/firefox
%if 0%{?suse_version} == 1315
%define sle_version 12
%endif
%define progdir %{_prefix}/%_lib/firefox
%define libgssapi libgssapi_krb5.so.2
%define gnome_confdir %{_sysconfdir}
%define gnome_dir     %{_prefix}
%gconf_schemas_prereq
%if 0%{?suse_version} > 1100
Requires(pre):  /usr/bin/gconftool-2 coreutils
%else
PreReq:         gconf2 coreutils
%endif

%description
This package provides SLED Look and Feel for MozillaFirefox.



Authors:
--------
    Petr Cerny <pcerny@suse.com>

%prep
cp %{SOURCE0} %{SOURCE8} .
sed -i 's,@HOMEPAGEURL@,%{homepage},' %{SOURCE4} %{SOURCE5}

%build

%install
install -d %{buildroot}%{progdir}
install -d %{buildroot}%{progdir}/browser
# custom bookmarks
install -d %{buildroot}%{progdir}/browser/defaults/profile
# apply SUSE defaults
# all applications
install -d %{buildroot}%{progdir}/defaults/pref
install -m0644 %{SOURCE6} %{buildroot}%{progdir}/defaults/pref/
# firefox
install -d %{buildroot}%{progdir}/browser/defaults/preferences
install -m0644 %{SOURCE3} %{buildroot}%{progdir}/browser/defaults/preferences/firefox-SLE.js
sed -i -e 's,@GSSAPI@,%{libgssapi},g' %{buildroot}%{progdir}/browser/defaults/preferences/firefox-SLE.js
# distribution.ini
install -d %{buildroot}%{progdir}/distribution
sed -e 's,%%VERSION%%,%{sle_version},g' \
   %{SOURCE5} > distribution.ini

install -d %{buildroot}%{progdir}/distribution/
install -m 0644 distribution.ini %{buildroot}%{progdir}/distribution/

# SCHEMA file
mkdir -p %{buildroot}%{gnome_confdir}/gconf/schemas
install -m 644 %{SOURCE4} \
               %{buildroot}%{gnome_confdir}/gconf/schemas/
%find_gconf_schemas

%clean
rm -rf %{buildroot}

%pre -f %{name}.schemas_pre

%preun -f %{name}.schemas_preun

%posttrans -f %{name}.schemas_posttrans

%files -f %{name}.schemas_list
%defattr(-,root,root)

%doc README.SUSE
%license COPYING
%{progdir}/defaults/pref/
%{progdir}/browser/
%{progdir}/browser/defaults/
%{progdir}/browser/defaults/preferences/
%{progdir}/browser/defaults/profile/
%{progdir}/distribution/

%changelog
* Thu Jul 11 2024 cgrobertson@suse.com
- change version to 128
* Thu Jun 29 2023 martin.sirringhaus@suse.com
- change version to 115
- Move bookmarks to https
* Tue Jul  5 2022 martin.sirringhaus@suse.com
- change version to 102
* Wed Aug 11 2021 cgrobertson@suse.com
- change version to 91
* Tue Jul  7 2020 martin.sirringhaus@suse.com
- change version to 78
* Tue Oct  8 2019 martin.sirringhaus@suse.com
- moved extensions preferences to core package (bsc#1153869)
* Fri Jun  7 2019 martin.sirringhaus@suse.com
- Fix bookmarks and clean up old files
* Fri Jun  7 2019 martin.sirringhaus@suse.com
- Fix wrongly displayed version in Help -> About (bsc#1087200)
* Thu Jun  6 2019 martin.sirringhaus@suse.com
- change version to 68
* Wed Jun  6 2018 pcerny@suse.com
- change version to 60
* Sun Jun 18 2017 pcerny@suse.com
- change version to 52
* Thu Jun 16 2016 pcerny@suse.com
- fix homepage in the GNOME schema file
* Thu Jun  9 2016 pcerny@suse.com
- remove extension part of the branding, since it is no longer
  needed
* Thu Jun  2 2016 pcerny@suse.com
- changing required Firefox versions in the branding extension
  as well as in the .spec file (requiring 45.*)
* Thu Nov 19 2015 pcerny@suse.com
- turn tracking protection on by default
* Wed Nov  4 2015 pcerny@suse.com
- changing version to 38
  (bumping up max supported Firefox version to 38.* in the extension as
  well)
* Fri Aug 14 2015 pcerny@suse.com
- bumped max Firefox version to 38.*
* Sat Dec  6 2014 meissner@suse.com
- version should be 31.0 instead of 31 to meet requirement
  from firefox
* Thu Jul 31 2014 pcerny@suse.com
- disable call home features
* Fri Jun 13 2014 pcerny@suse.com
- marked as compatible with Firefox 31
* Fri Mar 28 2014 pcerny@suse.com
- show protocol in URL
* Wed Feb 19 2014 pcerny@suse.com
- packaging license file
* Mon Feb 17 2014 cdenicolo@suse.com
- license update: BSD-3-Clause
  please use SPDX-filenames.
* Fri Feb 14 2014 pcerny@suse.com
- setting maximum supported Firefox version to 31
* Thu Dec  5 2013 pcerny@suse.com
- update for Firefox 24 ESR
* Mon Feb 25 2013 pcerny@suse.com
- bnc#803326 - default setting for new profiles
  * fixed setting default homepage
  * Personal Toolbar displayed by default
* Sat Jan 14 2012 pcerny@suse.com
- update for Firefox 10
- changed site icons in bookmarks
* Mon Dec 12 2011 pcerny@suse.com
- update for Firefox 8
* Tue Sep 20 2011 pcerny@suse.com
- update for Firefox 5+
* Wed May  5 2010 bgmerrell@novell.com
- Set the default home page according to bnc#461752
- Fix issue where the wrong distribution info was being shown in
  Firefox (bnc#569580).  This can be seen in "About Mozilla
  Firefox" in the Help menu.
* Mon Jul 13 2009 wr@rosenauer.org
- update to 3.5 to supplement FF3.5
* Wed Feb 25 2009 pwu@suse.de
- Workaround for (bnc#463136), will re-enable it later.
  Comment out 'pref("config.use_system_prefs", true)'
  in firefox-suse-default-prefs.js.
* Thu Jan  8 2009 hfiguiere@suse.de
- Change homepage URL. (bnc#461752)
* Mon Dec  8 2008 hfiguiere@suse.de
- Fix a typo in firefox-suse-default-prefs.js
* Fri Nov 21 2008 maw@suse.de
- Review and approve changes.
* Fri Nov 14 2008 wr@rosenauer.org
- Make sure that the base package is installed before installing
  the branding packages (needed for gconf schema update)
  (bnc#444682)
* Fri Nov  7 2008 maw@suse.de
- Review and approve changes.
* Tue Nov  4 2008 wr@rosenauer.org
- Enable the use of system preferences for the lockdown. (bnc#439844)
- Added the Firefox Gconf schema for system prefs (bnc#441646)
* Wed Oct 22 2008 wr@rosenauer.org
- bumped version to 3.0.3
- removed browser.link.open_external override; we are opening
  everything in a new tab; that also caused UI misbehaviour
  (bnc#430077, bmo#457092)
- Set browser.identity.ssl_domain.display to 1 (bnc#426263)
* Mon Oct  6 2008 sbrabec@suse.cz
- Conflict with other branding providers (FATE#304881).
* Fri Sep 26 2008 vuntz@suse.de
- Add COPYING file (bnc#426320).
* Wed Sep 10 2008 vuntz@suse.de
- New package, branched from MozillaFirefox-branding-openSUSE.
- Add SLED documentation bookmark, and remove openSUSE-related
  stuff. (fate#305003)
